=======
Credits
=======

Development Lead
----------------

* Roberto Di Remigio (@robertodr)
* Radovan Bast (@bast)

Contributors
------------

None yet. Why not be the first?


These lists were obtained 2019-02-08 by running ``git shortlog -sn``

